@@ -27,7 +27,14 @@
 *****************************************************************/
 
 dcl(MSG_ImportingDoc, "Importing Document..")
-dcl(MSG_BuildingDoc, "Building Document..")
+dcl(MSG_BuildingDoc,  "Building Document:")
+dcl(MSG_AutoRevision, "Autorevision")
+dcl(MSG_HistoryPartRestore1, "AbiWord cannot fully restore version %d of the document because the version information is incomplete.")
+dcl(MSG_HistoryPartRestore2, "The nearest version that can be restored fully is %d. Would you like to restore this version instead? To partially restore version %d press No.")
+dcl(MSG_HistoryPartRestore3, "To continue anyway, press OK.")
+dcl(MSG_HistoryPartRestore4, "To quit the restoration attempt, press Cancel.")
+dcl(MSG_HistoryNoRestore, "AbiWord cannot restore version %d of the document because the version information is missing.")
+dcl(MSG_HistoryConfirmSave, "You have to save changes to document %s before proceeding. Save now?")
 
 /* Default name for new, untitled document */
 dcl(UntitledDocument,			"Untitled%d")
@@ -39,6 +46,12 @@ dcl(STYLE_NORMAL,			"Normal")
 dcl(STYLE_HEADING1, 		"Heading 1")
 dcl(STYLE_HEADING2, 		"Heading 2")
 dcl(STYLE_HEADING3, 		"Heading 3")
+dcl(STYLE_HEADING4, 		"Heading 4")
+dcl(STYLE_TOCHEADING, 		"Contents Header")
+dcl(STYLE_TOCHEADING1, 		"Contents 1")
+dcl(STYLE_TOCHEADING2, 		"Contents 2")
+dcl(STYLE_TOCHEADING3, 		"Contents 3")
+dcl(STYLE_TOCHEADING4, 		"Contents 4")
 dcl(STYLE_BLOCKTEXT,		"Block Text")          
 dcl(STYLE_LOWERCASELIST,	"Lower Case List")     
 dcl(STYLE_UPPERCASTELIST,	"Upper Case List")     
@@ -74,6 +87,12 @@ dcl(DLG_Insert, 				"&Insert")
 dcl(DLG_Update, 				"Update")
 dcl(DLG_Apply,					"Apply")
 dcl(DLG_Delete, 				"Delete")
+dcl(DLG_Compare, 				"Compare")
+dcl(DLG_Select, 				"Select")
+dcl(DLG_Merge, 				    "Merge")
+dcl(DLG_Show, 				    "Show")
+dcl(DLG_Restore,			    "Restore")
+	
 /* Units */
 dcl(DLG_Unit_inch,				"inch")
 dcl(DLG_Unit_cm,				"cm")
@@ -228,20 +247,38 @@ dcl(DLG_ULANG_LangTitle,				"Set Language")
 dcl(DLG_ULANG_LangLabel,				"Select Language:")
 dcl(DLG_ULANG_AvailableLanguages,			"Available Languages")
 dcl(DLG_ULANG_SetLangButton,				"&Set Language")
-
+dcl(DLG_ULANG_DefaultLangLabel,         "Default language: ")
+dcl(DLG_ULANG_DefaultLangChkbox,        "Make default for document")
+	
 /* ClipArt Dialog */
 dcl(DLG_CLIPART_Title, "Clip Art")
 
 /* About Dialog */
 dcl(DLG_ABOUT_Title,					"About %s")
 
-	 /* image size dialog */
-	 dcl(DLG_Image_Title, "Image Properties")
-	 dcl(DLG_Image_Width, "Width:")
-	 dcl(DLG_Image_Height, "Height:")
-	 dcl(DLG_Image_Aspect, "Preserve aspect ratio")
-
+/* image size dialog */
+dcl(DLG_Image_Title, "Image Properties")
+dcl(DLG_Image_Width, "Width:")
+dcl(DLG_Image_Height, "Height:")
+dcl(DLG_Image_Aspect, "Preserve aspect ratio")
+dcl(DLG_Image_LblTitle, "Title:")
+dcl(DLG_Image_LblDescription, "Description:")
+dcl(DLG_Image_ImageSize, "Set Image Size")
+dcl(DLG_Image_ImageDesc, "Set Image Name")
+dcl(DLG_Image_TextWrapping, "Define Text Wrapping")
+dcl(DLG_Image_Placement, "Define Image Placement")
+dcl(DLG_Image_InLine, "Image placed in-line (no text wrapping)")
+dcl(DLG_Image_WrappedRight, "Text wrapped to the Right of the Image")
+dcl(DLG_Image_WrappedLeft, "Text wrapped to the Left of the Image")
+dcl(DLG_Image_WrappedBoth, "Text wrapped on both sides of the Image")
+dcl(DLG_Image_PlaceParagraph, "Position relative to nearest paragraph")
+dcl(DLG_Image_PlaceColumn, "Position relative to its Column")
+dcl(DLG_Image_PlacePage, "Position relative to its Page")
 
+/* ListDocuments Dialog */
+dcl(DLG_LISTDOCS_Title,					"Opened Documents")
+dcl(DLG_LISTDOCS_Heading1,				"Choose document from the list:")
+	
 /*
 For insert Table widget
 */
@@ -269,8 +306,10 @@ dcl(LANG_AR_EG, 							"Arabic (Egypt)")
 dcl(LANG_AR_SA, 							"Arabic (Saudi Arabia)")
 dcl(LANG_HY_AM, 							"Armenian")
 dcl(LANG_AS_IN, 							"Assamese")
+dcl(LANG_AST_ES, 							"Asturian (Spain)")
 dcl(LANG_EU_ES, 							"Basque")
 dcl(LANG_BE_BY, 							"Belarusian")
+dcl(LANG_BN_IN,                             "Bengali")
 dcl(LANG_BR_FR,								"Breton")		// Jordi 19/10/2002
 dcl(LANG_BG_BG, 							"Bulgarian")
 dcl(LANG_CA_ES, 							"Catalan")
@@ -302,29 +341,38 @@ dcl(LANG_DE_CH, 							"German (Switzerland)")
 dcl(LANG_EL_GR, 							"Greek")
 dcl(LANG_HA_NE, 							"Hausa (Niger)")
 dcl(LANG_HA_NG, 							"Hausa (Nigeria)")
+dcl(LANG_HAW_US,                            "Hawaiian")
 dcl(LANG_HE_IL, 							"Hebrew")
 dcl(LANG_HI_IN, 							"Hindi")
 dcl(LANG_HU_HU, 							"Hungarian")
 dcl(LANG_IS_IS, 							"Icelandic")
 dcl(LANG_ID_ID,	 							"Indonesian")
+dcl(LANG_IU_CA,                             "Inuktitut")
 dcl(LANG_IA,	 							"Interlingua")
 dcl(LANG_GA_IE, 							"Irish")
 dcl(LANG_IT_IT, 							"Italian (Italy)")
 dcl(LANG_JA_JP, 							"Japanese")
+dcl(LANG_KN_IN,                             "Kannada")
 dcl(LANG_KO_KR, 							"Korean")
+dcl(LANG_LO_LA,                             "Lao")
 dcl(LANG_LA_IT, 							"Latin (Renaissance)")	// Is _IT the right thing here?
 dcl(LANG_LV_LV, 							"Latvian")
 dcl(LANG_LT_LT, 							"Lithuanian")
 dcl(LANG_MK,								"Macedonian")	// Jordi 19/10/2002 Hipi: Why not mk-MK?
+dcl(LANG_MI_NZ,                             "Maori")
+dcl(LANG_MR_IN,                             "Marathi")
 dcl(LANG_MH_MH, 							"Marshallese (Marshall Islands)")
 dcl(LANG_MH_NR, 							"Marshallese (Nauru)")
+dcl(LANG_MN_MN,                             "Mongolian")
 dcl(LANG_NB_NO, 							"Norwegian Bokmal")
 dcl(LANG_NN_NO, 							"Norwegian Nynorsk")
 dcl(LANG_OC_FR,								"Occitan")		// Jordi 19/10/2002
 dcl(LANG_PL_PL, 							"Polish")
 dcl(LANG_PT_BR, 							"Portuguese (Brazil)")
 dcl(LANG_PT_PT, 							"Portuguese (Portugal)")
-dcl(LANG_QU_BO, 							"Quechua")
+dcl(LANG_PA_IN,                             "Punjabi (Gurmukhi)")
+dcl(LANG_PA_PK,                             "Punjabi (Shahmukhi)")
+dcl(LANG_QU_BO,                             "Quechua")
 dcl(LANG_RO_RO, 							"Romanian")
 dcl(LANG_RU_RU, 							"Russian (Russia)")
 dcl(LANG_SC_IT,								"Sardinian")	// Jordi 19/10/2002
@@ -333,7 +381,12 @@ dcl(LANG_SK_SK, 							"Slovak")				// or Slovakian?
 dcl(LANG_SL_SI, 							"Slovenian")
 dcl(LANG_ES_MX, 							"Spanish (Mexico)")
 dcl(LANG_ES_ES, 							"Spanish (Spain)")
+dcl(LANG_SW,                                "Swahili")
 dcl(LANG_SV_SE, 							"Swedish")
+dcl(LANG_SYR,                               "Syriac")
+dcl(LANG_TL_PH,                             "Tagalog")
+dcl(LANG_TA_IN,                             "Tamil")
+dcl(LANG_TE_IN,                             "Telugu")
 dcl(LANG_TH_TH, 							"Thai")
 dcl(LANG_TR_TR, 							"Turkish")
 dcl(LANG_UK_UA, 							"Ukrainian")
@@ -360,6 +413,8 @@ dcl(ENC_WEST_ASCII, 					"US-ASCII")
 /* Western Europe */
 dcl(ENC_WEST_ISO,						"Western European, ISO-8859-1")
 dcl(ENC_WEST_WIN,						"Western European, Windows Code Page 1252")
+dcl(ENC_US_DOS,						"Western European, DOS/Windows Code Page 437")
+dcl(ENC_MLNG_DOS,						"Western European, DOS/Windows Code Page 850")
 dcl(ENC_WEST_MAC,						"Western European, Macintosh")
 dcl(ENC_WEST_HP,						"Western European, HP")
 dcl(ENC_WEST_NXT,						"Western European, NeXT")
@@ -467,3 +522,33 @@ dcl(XIM_Methods, "Input Methods")
 //than ap_String_Id.h
 dcl(DLG_Options_Label_LangWithKeyboard,         "Change Language when changing keyboard")
 dcl(DLG_Options_Label_DirMarkerAfterClosingParenthesis, "Auto-insert direction markers")
+
+dcl(DLG_History_WindowLabel, "Document History")
+dcl(DLG_History_DocumentDetails, "Document Details")
+dcl(DLG_History_Path, "Document name:")
+dcl(DLG_History_Created, "Created:")
+dcl(DLG_History_Version, "Version:")
+dcl(DLG_History_LastSaved, "Last saved:")
+dcl(DLG_History_EditTime, "Editing time:")
+dcl(DLG_History_Id, "Identifier:")
+
+dcl(DLG_History_List_Title, "Version history")
+dcl(DLG_History_Version_Version, "Version")
+dcl(DLG_History_Version_Started, "Created")
+dcl(DLG_History_Version_AutoRevisioned, "Auto-revision")
+	
+dcl(DLG_DocComparison_WindowLabel, "Document Comparison")
+dcl(DLG_DocComparison_DocsCompared, "Documents compared")
+dcl(DLG_DocComparison_Results, "Results")
+dcl(DLG_DocComparison_Relationship, "Relationship:")
+dcl(DLG_DocComparison_Content, "Content:")
+dcl(DLG_DocComparison_Fmt, "Format:")
+dcl(DLG_DocComparison_Styles, "Styles:")
+
+dcl(DLG_DocComparison_Identical, "identical")
+dcl(DLG_DocComparison_Unrelated, "unrelated")
+dcl(DLG_DocComparison_Siblings, "siblings")
+dcl(DLG_DocComparison_Diverging, "diverging after version %d of %s")
+dcl(DLG_DocComparison_DivergingPos, "diverging after document position %d")
+dcl(DLG_DocComparison_TestSkipped, "(test skipped)")
+dcl(DLG_DocComparison_Different, "different")
