@@ -23,7 +23,8 @@
 ** MORE THAN ONE TIME.
 ******************************************************************
 *****************************************************************/
-
+// Default Heading used in TOC
+dcl(TOC_TocHeading, "Table of Contents")
 // Message Boxes used in AP_EditMethods
 dcl(MSG_SaveFailed, 	"Could not write to the file %s.")
 dcl(MSG_SaveFailedWrite,		"Writing error when attempting to save %s")
@@ -50,6 +51,12 @@ dcl(MSG_PrintStatus,			"Printing page %d of %d")
 dcl(MSG_RevertFile, "Revert file to last unsaved state?")
 dcl(MSG_PrintingDoc, "Printing Document..")
 dcl(MSG_NoBreakInsideTable, "Can not insert a Break inside a table")
+dcl(MSG_NoBreakInsideFrame, "Can not insert a Break inside a text box")
+dcl(MSG_MergeDocsNotRelated, "The documents you are trying to merge are unrelated. AbiWord will attempt to merge them, but the result might be meaningless.")
+dcl(MSG_AutoRevisionOffWarning, "Are you sure you do not want to maintain full history record? If you proceed, you will not be able to restore earlier versions of this document.")
+
+// Abi has just crashed
+dcl(MSG_Exception, "A fatal error has just occurred. Abiword is going to shutdown.\nThe current document has been saved to disc with a \".saved\" extension.")
 
 // Status Bar Messages
 dcl(PageInfoField,				"Page: %d/%d")
@@ -82,6 +89,9 @@ dcl(DLG_NEW_Tab1_WP1,			"Create a new blank document")
 dcl(DLG_NEW_Tab1_FAX1,			"Create a fax")
 
 dcl(DLG_InsertButton,			"&Insert")
+dcl(DLG_CloseButton,			"&Close")
+dcl(DLG_ApplyButton,			"&Apply")
+dcl(DLG_HelpButton,			    "&Help")
 
 /* Tab Types - the order here must be consistent with the
    order in fl_BlockLayout.h*/
@@ -146,6 +156,35 @@ dcl(DLG_FormatFootnotes_EndPlaceEndSec,    "Place at end of section")
 dcl(DLG_FormatFootnotes_EndPlacement,      "Placement")
 dcl(DLG_FormatFootnotes_FootnoteRestart,   "Numbering")
 
+/* Format TOC dialog */
+dcl(DLG_FormatTOC_Title,                  "Format Table of Contents")
+dcl(DLG_FormatTOC_General,                "General")
+dcl(DLG_FormatTOC_LayoutDetails,          "Layout Details")
+dcl(DLG_FormatTOC_None,                   "None")
+dcl(DLG_FormatTOC_HasHeading,             "&Has Heading")
+dcl(DLG_FormatTOC_HeadingText,            "H&eading text:")
+dcl(DLG_FormatTOC_HeadingStyle,           "Heading style:")
+dcl(DLG_FormatTOC_ChangeStyle,            "Change Style")
+dcl(DLG_FormatTOC_LevelDefs,              "Define Main Properties")
+dcl(DLG_FormatTOC_HasLabel,               "H&as label")
+dcl(DLG_FormatTOC_FillStyle,              "Fill style:")
+dcl(DLG_FormatTOC_DispStyle,              "Display style:")
+dcl(DLG_FormatTOC_DetailsTop,             "Label Definitions")
+dcl(DLG_FormatTOC_StartAt,                "&Start at:")
+dcl(DLG_FormatTOC_TextBefore,             "Text &before:")
+dcl(DLG_FormatTOC_NumberingType,          "&Numbering type:")
+dcl(DLG_FormatTOC_TextAfter,              "Text &after:")
+dcl(DLG_FormatTOC_InheritLabel,           "&Inherit label")
+dcl(DLG_FormatTOC_TabLeader,              "&Tab leader:")
+dcl(DLG_FormatTOC_Indent,                 "I&ndent:")
+dcl(DLG_FormatTOC_PageNumbering,          "&Page numbering:")
+dcl(DLG_FormatTOC_DetailsTabPage,         "Tabs and Page Numbering")
+dcl(DLG_FormatTOC_Level1,                 "Level 1")
+dcl(DLG_FormatTOC_Level2,                 "Level 2")
+dcl(DLG_FormatTOC_Level3,                 "Level 3")
+dcl(DLG_FormatTOC_Level4,                 "Level 4")
+
+
 
 /* Word Count dialog */
 dcl(DLG_WordCount_WordCountTitle,	"Word Count")
@@ -216,6 +255,16 @@ dcl(DLG_Styles_ErrStyleCantDelete, "Cannot delete this style")
 dcl(DLG_Styles_ErrBlankName, "Style name cannot be left blank")
 dcl(DLG_Styles_StylesLocked,	"Disable all formatting commands, except styles")
 
+/* Stylist dialog */
+
+dcl(DLG_Stylist_Title, "Stylist")
+dcl(DLG_Stylist_ListStyles, "List Styles")
+dcl(DLG_Stylist_HeadingStyles, "Heading Styles")
+dcl(DLG_Stylist_FootnoteStyles, "Note Styles")
+dcl(DLG_Stylist_UserStyles, "User defined Styles")
+dcl(DLG_Stylist_MiscStyles, "Miscellaneous Styles")
+dcl(DLG_Stylist_Styles, "Styles")
+
 /* Paragraph dialog */
 dcl(DLG_Para_ParaTitle, 		"Paragraph")
 
@@ -235,8 +284,8 @@ dcl(DLG_Para_SpacingAtLeast,	"At least")
 dcl(DLG_Para_SpacingExactly,	"Exactly")
 dcl(DLG_Para_SpacingMultiple,	"Multiple")
 
-dcl(DLG_Para_TabLabelIndentsAndSpacing, "&Indents and Spacing")
-dcl(DLG_Para_TabLabelLineAndPageBreaks, "Line and &Page Breaks")
+dcl(DLG_Para_TabLabelIndentsAndSpacing, "Indents and Spacing")
+dcl(DLG_Para_TabLabelLineAndPageBreaks, "Line and Page Breaks")
 
 dcl(DLG_Para_LabelAlignment,	"Ali&gnment:")
 dcl(DLG_Para_LabelBy,			"B&y:")
@@ -300,36 +349,47 @@ dcl(DLG_Options_Btn_Save,				"Sa&ve")
 dcl(DLG_Options_Btn_Apply,				"Apply")
 dcl(DLG_Options_Btn_Default,			"De&faults")
 
+dcl(DLG_Options_SpellCheckingTitle,		"Spell Checking")
+
 dcl(DLG_Options_Label_SpellCheckAsType, "Check s&pelling as you type")
 dcl(DLG_Options_Label_SpellHideErrors,	"Hide &spelling errors in the document")
+dcl(DLG_Options_Label_SpellHighlightMisspelledWords, "&Highlight misspelled words") // Opposite of HideErrors
+										      // should be merged one day
 dcl(DLG_Options_Label_SpellSuggest, 	"A&lways suggest corrections")
 dcl(DLG_Options_Label_SpellMainOnly,	"Suggest from &main dictionary only")
 dcl(DLG_Options_Label_SpellUppercase,	"Words in &UPPERCASE")
 dcl(DLG_Options_Label_SpellNumbers, 	"Words with num&bers")
-dcl(DLG_Options_Label_SpellInternet,	"Internet and &file addresses")
 dcl(DLG_Options_Label_SpellCustomDict,	"Custom Dictionary:")
 dcl(DLG_Options_Label_SpellIgnoredWord, "Ignored words:")
+dcl(DLG_Options_Label_SpellIgnoreWords, "Ignore Words")
 dcl(DLG_Options_Btn_CustomDict, 		"&Dictionary...")
 dcl(DLG_Options_Btn_IgnoreReset,		"&Reset")
 dcl(DLG_Options_Btn_IgnoreEdit, 		"&Edit")
 dcl(DLG_Options_Label_SpellAutoReplace, "Auto replace misspelled words")
+dcl(DLG_Options_Label_SpellDictionaries,	"Dictionaries")
 
 dcl(DLG_Options_Label_SmartQuotesEnable,"&Enable smart quotes")
 dcl(DLG_Options_Label_DefaultPageSize, "Default page size")
 
 dcl(DLG_Options_Label_DirectionRtl, "Default to right-to-left direction of text")
 dcl(DLG_Options_Label_BiDiOptions, "Bi-Directional Options")
-dcl(DLG_Options_Label_SaveContextGlyphs, "Save visual glyph shapes")
 dcl(DLG_Options_Label_HebrewContextGlyphs, "Use glyph shaping for Hebrew")
 
+dcl(DLG_Options_Label_UI,			"User Interface")
+dcl(DLG_Options_Label_AppStartup,		"Application Startup")
+dcl(DLG_Options_Label_Documents,		"Documents")
+
 dcl(DLG_Options_Label_UILang, 					"User Interface Language")
 dcl(DLG_Options_Label_LangSettings, 			"Language settings")
 
 
 dcl(DLG_Options_Label_AutoSave, 		"Auto Save")
-dcl(DLG_Options_Label_AutoSaveCurrent,	"Auto &save current file every")
+dcl(DLG_Options_Label_AutoSaveUnderline, 	"Auto &Save")
+dcl(DLG_Options_Label_AutoSaveCurrent,		"Auto &save current file every")
+dcl(DLG_Options_Label_AutoSaveInterval, 	"&Interval:")
 dcl(DLG_Options_Label_Minutes,			"minutes")
-dcl(DLG_Options_Label_WithExtension,	"With extension:")
+dcl(DLG_Options_Label_FileExtension,		"&File extension:")
+dcl(DLG_Options_Label_WithExtension,		"With extension:")
 
 dcl(DLG_Options_Label_PrefsAutoSave,	"&Automatically save this Scheme")
 dcl(DLG_Options_Label_PrefsCurrentScheme,	"&Current Preferences Scheme")
@@ -344,6 +404,7 @@ dcl(DLG_Options_Label_ViewUnits,		"&Units:")
 dcl(DLG_Options_Label_ViewCursorBlink,	"Cursor &blink")
 dcl(DLG_Options_Label_ViewStandardTB,		"Standard Toolbar")
 dcl(DLG_Options_Label_ViewFormatTB, 	"Format Toolbar")
+dcl(DLG_Options_Label_ViewTableTB,		"Table Toolbar")
 dcl(DLG_Options_Label_ViewExtraTB,		"Extra Toolbar")
 dcl(DLG_Options_Label_ViewStatusBar,		"&Status bar")
 dcl(DLG_Options_Label_ViewViewFrame,	"View...")
@@ -357,6 +418,7 @@ dcl(DLG_Options_Label_CheckWhiteForTransparent, "Allow screen colors other than
 dcl(DLG_Options_Label_ChooseForTransparent, "Choose Screen Color")
 dcl(DLG_Options_Label_ColorChooserLabel,	"Choose screen color for AbiWord")
 dcl(DLG_Options_Label_InvalidRangeForAutoSave,	"You should choose a range from 1 to 120 for the auto save frequency")
+dcl(DLG_Options_Prompt_YouMustRestart,	"The new user interface language will take effect the next time that you start the application")
 
 dcl(DLG_Options_Prompt_IgnoreResetCurrent,	"Do you want to reset ignored words in the current document?")
 dcl(DLG_Options_Prompt_IgnoreResetAll,		"Do you want to reset ignored words in all the documents?")
@@ -410,18 +472,53 @@ dcl(DLG_MergeCells_Right,	    	     "Merge Right")
 dcl(DLG_MergeCells_Above,	    	     "Merge Above")
 dcl(DLG_MergeCells_Below,	    	     "Merge Below")
 
+
+dcl(DLG_SplitCellsTitle,	    	     "Split Cells")
+dcl(DLG_SplitCells_Frame,	    	     "Split Cells")
+dcl(DLG_SplitCells_Left,	    	     "Split on Left Side")
+dcl(DLG_SplitCells_HoriMid,	    	     "Split in Middle")
+dcl(DLG_SplitCells_Right,	    	     "Split on Right Side")
+dcl(DLG_SplitCells_Above,	    	     "Split on Top Side")
+dcl(DLG_SplitCells_VertMid,	    	     "Split in Middle")
+dcl(DLG_SplitCells_Below,	    	     "Split on Bottom Side")
+
+
+dcl(DLG_FormatFrameTitle,	    	     "Format Text Box")
+dcl(DLG_FormatFrame_Borders,	   	     "Borders")
+dcl(DLG_FormatFrame_Background,    	     "Background")
+dcl(DLG_FormatFrame_Border_Color,   	 "Border color:")
+dcl(DLG_FormatFrame_Background_Color,    "Background color:")
+dcl(DLG_FormatFrame_Color,		     "Color:")
+dcl(DLG_FormatFrame_Preview,	   	     "Preview")
+dcl(DLG_FormatFrame_SetImageBackground,  "Image For Background")
+dcl(DLG_FormatFrame_SetImage,            "Set Image")
+dcl(DLG_FormatFrame_SelectImage,         "Select image from File")
+dcl(DLG_FormatFrame_NoImageBackground,   "Set no image")
+dcl(DLG_FormatFrame_TextWrapping,        "Text Wrapping")
+dcl(DLG_FormatFrame_SetTextWrapping,     "Set Text Wrapping")
+dcl(DLG_FormatFrame_SetToParagraph,      "Position to Paragraph")
+dcl(DLG_FormatFrame_SetToColumn,         "Position to Column")
+dcl(DLG_FormatFrame_SetToPage,           "Position to Page")
+dcl(DLG_FormatFrame_PositionTo,          "Position Text Box")
+
 dcl(DLG_FormatTableTitle,	    	     "Format Table")
 dcl(DLG_FormatTable_Borders,	   	     "Borders")
 dcl(DLG_FormatTable_Background,    	     "Background")
-dcl(DLG_FormatTable_Border_Color,    	 "Border color:")
+dcl(DLG_FormatTable_Border_Color,   	 "Border color:")
 dcl(DLG_FormatTable_Background_Color,    "Background color:")
-dcl(DLG_FormatTable_Color,		     "Color:")
+dcl(DLG_FormatTable_Color,		         "Color:")
+dcl(DLG_FormatTable_Thickness,	         "Thickness:")
 dcl(DLG_FormatTable_Preview,	   	     "Preview")
 dcl(DLG_FormatTable_Apply_To,	   	     "Apply to:")
 dcl(DLG_FormatTable_Apply_To_Selection,  "Selection")
 dcl(DLG_FormatTable_Apply_To_Row,        "Row")
 dcl(DLG_FormatTable_Apply_To_Column,     "Column")
 dcl(DLG_FormatTable_Apply_To_Table,	     "Table")
+dcl(DLG_FormatTable_SetImageBackground,  "Image For Background")
+dcl(DLG_FormatTable_SetImage,            "Set Image")
+dcl(DLG_FormatTable_SelectImage,         "Select image from File")
+dcl(DLG_FormatTable_NoImageBackground,   "Set no image")
+
 
 dcl(DLG_Field_FieldTitle,				"Insert field")
 dcl(DLG_Field_FieldTitle_Capital,			"Insert Field")
@@ -444,9 +541,13 @@ dcl(FIELD_Type_Numbers, 		"Numbers")
 dcl(FIELD_Type_PieceTable,		"Piece Table")
 dcl(FIELD_Datetime_CurrentTime, 	"Current Time")
 dcl(FIELD_Numbers_PageNumber,		"Page Number")
+dcl(FIELD_Numbers_TOCPageNumber,		"Table of Contents Page")
+dcl(FIELD_Numbers_TOCListLabel,		"Table of Contents List Label")
 dcl(FIELD_Numbers_PageReference,	"Page Reference")
 dcl(FIELD_Numbers_PagesCount,		"Number of Pages")
 dcl(FIELD_Numbers_ListLabel,		"List Label")
+dcl(FIELD_Numbers_TableSumCols,		"Sum a Table Row")
+dcl(FIELD_Numbers_TableSumRows,		"Sum a Table Column")
 dcl(FIELD_Numbers_WordCount, "Word Count")
 dcl(FIELD_Numbers_CharCount, "Character Count")
 dcl(FIELD_Numbers_LineCount, "Line Count")
@@ -564,6 +665,14 @@ dcl(DLG_Lists_Apply_Current,				"Apply to Current List")
 dcl(DLG_Lists_Start_Sub,				"Start Sublist")
 dcl(DLG_Lists_Resume,				 "Attach to Previous List")
 dcl(DLG_Lists_SetDefault,				 "Set Default Values")
+dcl(DLG_Lists_PageProperties,				 "List Properties")
+dcl(DLG_Lists_PageFolding,				 "Text Folding")
+dcl(DLG_Lists_FoldingLevelexp,				 "Hide text below List Levels")
+dcl(DLG_Lists_FoldingLevel0,				 "No Folding")
+dcl(DLG_Lists_FoldingLevel1,				 "Fold below level 1")
+dcl(DLG_Lists_FoldingLevel2,				 "Fold below level 2")
+dcl(DLG_Lists_FoldingLevel3,				 "Fold below level 3")
+dcl(DLG_Lists_FoldingLevel4,				 "Fold below level 4")
 
 	 /* page numbers dialog */
 dcl(DLG_PageNumbers_Title,			 "Page Numbers")
@@ -598,9 +707,10 @@ dcl(DLG_PageSetup_Footer, "&Footer:")
 dcl(DLG_PageSetup_Bottom, "&Bottom:")
 dcl(DLG_PageSetup_Left, "&Left:")
 dcl(DLG_PageSetup_Right, "&Right:")
-dcl(DLG_PageSetup_Margin, "&Margin")
+dcl(DLG_PageSetup_Margin, "Margin")
 dcl(DLG_PageSetup_ErrBigMargins, "The margins selected are too large to fit on the page.")
 
+dcl(MSG_AutoMerge, "Automerge")
 dcl(MSG_DirectionModeChg,	"You have changed the direction mode.")
 dcl(MSG_DefaultDirectionChg,"You have changed the default direction.")
 dcl(MSG_AfterRestartNew, "This change will only take effect when you restart AbiWord or create a new document.")
@@ -608,6 +718,7 @@ dcl(MSG_BookmarkNotFound, "Bookmark \"%s\" was not found in this document.")
 dcl(MSG_HyperlinkNoSelection, "You must select a portion of the document before inserting a hyperlink.")
 dcl(MSG_HyperlinkNoBookmark, "Warning: the bookmark you provided [%s] does not exist.")
 dcl(MSG_HyperlinkCrossesBoundaries, "The text to which the hyperlink is to be attached must be within a single paragraph.")
+dcl(MSG_HiddenRevisions, "This document contains revisions which are currently hidden from view. Please see AbiWord documentation for information on working with revisions.")
 
 dcl(DLG_ToggleCase_Title, "Change Case")
 dcl(DLG_ToggleCase_SentenceCase, "Sentence case")
@@ -671,8 +782,10 @@ dcl(DLG_MarkRevisions_Comment2Label, "Comment to be associated with the revision
 	/* List revisions dialog */
 dcl(DLG_ListRevisions_Title, "Select Revision")
 dcl(DLG_ListRevisions_Column1Label, "Revision ID")
-dcl(DLG_ListRevisions_Column2Label, "Comment")
+dcl(DLG_ListRevisions_Column2Label, "Date")
+dcl(DLG_ListRevisions_Column3Label, "Comment")
 dcl(DLG_ListRevisions_Label1, "Existing revisions:")
+dcl(DLG_ListRevisions_LevelZero, "(All revisions visible)")
 
 
 dcl(WORD_PassRequired, "Password required, this is an encrypted document")
@@ -738,6 +851,7 @@ dcl(MENU_LABEL__BOGUS2__," ")
 dcl(MENU_LABEL_OPEN_TEMPLATE,"Open Template")
 dcl(MENU_LABEL_FILE,"&File")
 dcl(MENU_LABEL_FILE_NEW,"&New")
+dcl(MENU_LABEL_FILE_NEW_USING_TEMPLATE,"&New using Template")
 dcl(MENU_LABEL_FILE_OPEN,"&Open")
 dcl(MENU_LABEL_FILE_CLOSE,"&Close")
 dcl(MENU_LABEL_FILE_SAVE,"&Save")
@@ -775,8 +889,12 @@ dcl(MENU_LABEL_EDIT_SELECTALL,"Select A&ll")
 dcl(MENU_LABEL_EDIT_FIND,"&Find")
 dcl(MENU_LABEL_EDIT_REPLACE,"R&eplace")
 dcl(MENU_LABEL_EDIT_GOTO,"&Go To")
-dcl(MENU_LABEL_INSERT_INSERTHEADER,"Insert Header")
-dcl(MENU_LABEL_INSERT_INSERTFOOTER,"Insert Footer")
+dcl(MENU_LABEL_EDIT_DELETEFRAME,"Delete Text Box")
+dcl(MENU_LABEL_EDIT_CUT_FRAME,"Cut Text Box")
+dcl(MENU_LABEL_EDIT_COPY_FRAME,"Copy Text Box")
+dcl(MENU_LABEL_EDIT_SELECT_FRAME,"Select Text Box")
+dcl(MENU_LABEL_INSERT_HEADER,"Header")
+dcl(MENU_LABEL_INSERT_FOOTER,"Footer")
 dcl(MENU_LABEL_EDIT_EDITHEADER,"Edit Header")
 dcl(MENU_LABEL_EDIT_EDITFOOTER,"Edit Footer")
 dcl(MENU_LABEL_EDIT_REMOVEHEADER,"Remove Header")
@@ -786,10 +904,10 @@ dcl(MENU_LABEL_VIEW_NORMAL,"&Normal Layout")
 dcl(MENU_LABEL_VIEW_WEB,"&Web Layout")
 dcl(MENU_LABEL_VIEW_PRINT,"&Print Layout")
 dcl(MENU_LABEL_VIEW_TOOLBARS,"&Toolbars")
-dcl(MENU_LABEL_VIEW_TB_STD,"&Standard")
-dcl(MENU_LABEL_VIEW_TB_FORMAT,"&Formatting")
-dcl(MENU_LABEL_VIEW_TB_TABLE, "&Table")
-dcl(MENU_LABEL_VIEW_TB_EXTRA,"&Extra")
+dcl(MENU_LABEL_VIEW_TB_1,"&1 %s")
+dcl(MENU_LABEL_VIEW_TB_2,"&2 %s")
+dcl(MENU_LABEL_VIEW_TB_3,"&3 %s")
+dcl(MENU_LABEL_VIEW_TB_4,"&4 %s")
 dcl(MENU_LABEL_VIEW_LOCK_TB_LAYOUT,"&Lock layout")
 dcl(MENU_LABEL_VIEW_DEFAULT_TB_LAYOUT,"&Reset to default layout")
 dcl(MENU_LABEL_VIEW_RULER,"Show &Ruler")
@@ -810,18 +928,25 @@ dcl(MENU_LABEL_INSERT,"&Insert")
 dcl(MENU_LABEL_INSERT_BREAK,"&Break")
 dcl(MENU_LABEL_INSERT_PAGENO,"Page N&umbers")
 dcl(MENU_LABEL_INSERT_DATETIME,"Date and &Time")
+dcl(MENU_LABEL_INSERT_TEXTBOX, "Text Box")
 dcl(MENU_LABEL_INSERT_MAILMERGE, "&Mail Merge Field")
 dcl(MENU_LABEL_INSERT_FIELD,"&Field")
-dcl(MENU_LABEL_INSERT_FILE,"&Insert File")
+dcl(MENU_LABEL_INSERT_FILE,"F&ile")
 dcl(MENU_LABEL_INSERT_SYMBOL,"Sy&mbol")
 dcl(MENU_LABEL_INSERT_ENDNOTE,"&Endnote")
 dcl(MENU_LABEL_INSERT_FOOTNOTE,"Foot&note")
+dcl(MENU_LABEL_INSERT_TABLEOFCONTENTS,"Table of Contents")
 dcl(MENU_LABEL_INSERT_PICTURE,"&Picture")
 dcl(MENU_LABEL_INSERT_CLIPART,"&Clip Art")
 dcl(MENU_LABEL_INSERT_GRAPHIC,"&From File")
 dcl(MENU_LABEL_INSERT_BOOKMARK,"Boo&kmark")
 dcl(MENU_LABEL_INSERT_HYPERLINK,"&Hyperlink")
+dcl(MENU_LABEL_INSERT_GOTO_HYPERLINK,"&Jump to hyperlink")
+dcl(MENU_LABEL_INSERT_EDIT_HYPERLINK,"&Edit hyperlink")
 dcl(MENU_LABEL_INSERT_DELETE_HYPERLINK,"&Delete hyperlink")
+dcl(MENU_LABEL_INSERT_DIRECTIONMARKER, "&Direction Marker")
+dcl(MENU_LABEL_INSERT_DIRECTIONMARKER_LRM, "&LRM")
+dcl(MENU_LABEL_INSERT_DIRECTIONMARKER_RLM, "&RLM")
 dcl(MENU_LABEL_FORMAT,"F&ormat")
 dcl(MENU_LABEL_FMT, "Te&xt Formatting")
 dcl(MENU_LABEL_FMT_LANGUAGE,"Set &Language")
@@ -832,9 +957,13 @@ dcl(MENU_LABEL_FMT_DOCUMENT,"&Document")
 dcl(MENU_LABEL_FMT_BORDERS,"Borders and Shading")
 dcl(MENU_LABEL_FMT_HDRFTR,"Header/Footers")
 dcl(MENU_LABEL_FMT_FOOTNOTES,"Footnotes and Endnotes")
+dcl(MENU_LABEL_FMT_TABLEOFCONTENTS,"Table of Contents")
 dcl(MENU_LABEL_FMT_COLUMNS,"&Columns")
 dcl(MENU_LABEL_FMT_TOGGLECASE,"C&hange Case")
-dcl(MENU_LABEL_FMT_BACKGROUND,"Back&ground")
+dcl(MENU_LABEL_FMT_BACKGROUND,"Page Background")
+dcl(MENU_LABEL_FMT_BACKGROUND_PAGE_COLOR,"Page C&olor")
+dcl(MENU_LABEL_FMT_BACKGROUND_PAGE_IMAGE,"Page Image")
+dcl(MENU_LABEL_FMT_STYLIST, "Sty&list")
 dcl(MENU_LABEL_FMT_STYLE,"St&yle")
 dcl(MENU_LABEL_FMT_STYLE_DEFINE, "&Create and Modify")
 dcl(MENU_LABEL_FMT_IMPORTSTYLES,"&Import Styles")
@@ -848,6 +977,12 @@ dcl(MENU_LABEL_FMT_TOPLINE,"Topline")
 dcl(MENU_LABEL_FMT_BOTTOMLINE,"Bottomline")
 dcl(MENU_LABEL_FMT_SUPERSCRIPT,"Supe&rscript")
 dcl(MENU_LABEL_FMT_SUBSCRIPT,"&Subscript")
+dcl(MENU_LABEL_FMT_FRAME,"Text Box")
+dcl(MENU_LABEL_FMT_IMAGE, "&Image")
+dcl(MENU_LABEL_FMT_DIRECTION, "D&irectional")
+dcl(MENU_LABEL_FMT_DIRECTION_DD_RTL, "RTL &Paragraph")
+dcl(MENU_LABEL_FMT_DIRECTION_DO_LTR, "&Left-to-right text")
+dcl(MENU_LABEL_FMT_DIRECTION_DO_RTL, "&Right-to-left text")
 dcl(MENU_LABEL_TOOLS,"&Tools")
 dcl(MENU_LABEL_TOOLS_SPELLING,"&Spelling")
 dcl(MENU_LABEL_TOOLS_SPELL,"Check &Spelling")
@@ -859,11 +994,22 @@ dcl(MENU_LABEL_TOOLS_LANGUAGE,"&Language")
 dcl(MENU_LABEL_TOOLS_PLUGINS,"&Plugins")
 dcl(MENU_LABEL_TOOLS_SCRIPTS,"S&cripts")
 dcl(MENU_LABEL_TOOLS_MAILMERGE,"&Mail Merge")
+dcl(MENU_LABEL_TOOLS_HISTORY,"&Document History")
+dcl(MENU_LABEL_TOOLS_HISTORY_SHOW,"&Show History")
+dcl(MENU_LABEL_TOOLS_REVISIONS_AUTO,"&Maintain Full History")
 dcl(MENU_LABEL_TOOLS_REVISIONS,"&Revisions")
 dcl(MENU_LABEL_TOOLS_REVISIONS_MARK,"&Mark revisions while typing")
+dcl(MENU_LABEL_TOOLS_REVISIONS_SHOW,"S&how revisions")
+dcl(MENU_LABEL_TOOLS_REVISIONS_SHOW_AFTER,"Show document a&fter revisions")
+dcl(MENU_LABEL_TOOLS_REVISIONS_SHOW_AFTERPREV,"Show document after &previous revisions")
+dcl(MENU_LABEL_TOOLS_REVISIONS_SHOW_BEFORE,"Show document &before revisions")
 dcl(MENU_LABEL_TOOLS_REVISIONS_SET_VIEW_LEVEL,"&Select revision")
 dcl(MENU_LABEL_TOOLS_REVISIONS_ACCEPT_REVISION,"&Accept revision")
 dcl(MENU_LABEL_TOOLS_REVISIONS_REJECT_REVISION,"&Reject revision")
+dcl(MENU_LABEL_TOOLS_REVISIONS_FIND_NEXT,"Find &next revision")
+dcl(MENU_LABEL_TOOLS_REVISIONS_FIND_PREV,"Find &previous revision")
+dcl(MENU_LABEL_TOOLS_REVISIONS_COMPARE_DOCUMENTS,"&Compare documents")
+dcl(MENU_LABEL_TOOLS_REVISIONS_MERGE_DOCUMENTS,"M&erge documents")
 dcl(MENU_LABEL_TABLE, "T&able")
 dcl(MENU_LABEL_TABLE_INSERT, "&Insert")
 dcl(MENU_LABEL_TABLE_INSERT_TABLE, "&Table")
@@ -875,6 +1021,8 @@ dcl(MENU_LABEL_TABLE_INSERT_ROWS_BEFORE, "Rows &Above")
 dcl(MENU_LABEL_TABLE_INSERT_ROWS_AFTER, "Rows &Below")
 dcl(MENU_LABEL_TABLE_INSERTROW, "Insert &Rows")
 dcl(MENU_LABEL_TABLE_INSERT_CELLS, "&Cells")
+dcl(MENU_LABEL_TABLE_INSERT_SUMCOLS, "Sum a Row")
+dcl(MENU_LABEL_TABLE_INSERT_SUMROWS, "Sum a Column")
 dcl(MENU_LABEL_TABLE_DELETE, "&Delete")
 dcl(MENU_LABEL_TABLE_DELETE_TABLE, "&Table")
 dcl(MENU_LABEL_TABLE_DELETETABLE, "Delete Tabl&e")
@@ -893,19 +1041,26 @@ dcl(MENU_LABEL_TABLE_SPLIT_CELLS, "S&plit Cells")
 dcl(MENU_LABEL_TABLE_SPLIT_TABLE, "Spli&t Table")
 dcl(MENU_LABEL_TABLE_FORMAT, "&Format Table")
 dcl(MENU_LABEL_TABLE_AUTOFIT, "&Autofit Table")
+dcl(MENU_LABEL_TABLE_TEXTTOTABLE, "Convert Text to Table")
 dcl(MENU_LABEL_TABLE_HEADING_ROWS_REPEAT, "Repeat Row as Heading")
 dcl(MENU_LABEL_TABLE_SORT, "So&rt Table")
+dcl(MENU_LABEL_TABLE_SORTROWSASCEND, "Sort Rows in Ascending Order")
+dcl(MENU_LABEL_TABLE_SORTROWSDESCEND, "Sort Rows in Descending Order")
+dcl(MENU_LABEL_TABLE_SORTCOLSASCEND, "Sort Columns in Ascending Order")
+dcl(MENU_LABEL_TABLE_SORTCOLSDESCEND, "Sort Columns in Descending Order")
 
 // the following two strings are identical to the two above, so I will
 // just alias them
 #define AP_STRING_ID_MENU_LABEL_CONTEXT_REVISIONS_REJECT_REVISION AP_STRING_ID_MENU_LABEL_TOOLS_REVISIONS_REJECT_REVISION
 #define AP_STRING_ID_MENU_LABEL_CONTEXT_REVISIONS_ACCEPT_REVISION AP_STRING_ID_MENU_LABEL_TOOLS_REVISIONS_ACCEPT_REVISION
+#define AP_STRING_ID_MENU_LABEL_CONTEXT_REVISIONS_FIND_NEXT AP_STRING_ID_MENU_LABEL_TOOLS_REVISIONS_FIND_NEXT
+#define AP_STRING_ID_MENU_LABEL_CONTEXT_REVISIONS_FIND_PREV AP_STRING_ID_MENU_LABEL_TOOLS_REVISIONS_FIND_PREV
 dcl(MENU_LABEL_ALIGN,"&Align")
 dcl(MENU_LABEL_ALIGN_LEFT,"&Left")
 dcl(MENU_LABEL_ALIGN_CENTER,"&Center")
 dcl(MENU_LABEL_ALIGN_RIGHT,"&Right")
 dcl(MENU_LABEL_ALIGN_JUSTIFY,"&Justify")
-dcl(MENU_LABEL_WEB_WEBPREVIEW,"&As web page")
+dcl(MENU_LABEL_WEB_WEBPREVIEW,"&In web browser")
 dcl(MENU_LABEL_WEB_SAVEASWEB,"&Save web page")
 dcl(MENU_LABEL_WINDOW,"&Documents")
 dcl(MENU_LABEL_WINDOW_NEW,"&New Window")
@@ -985,13 +1140,13 @@ dcl(MENU_LABEL_AUTOTEXT_EMAIL_3,"%s")
 dcl(MENU_LABEL_AUTOTEXT_EMAIL_4,"%s")
 dcl(MENU_LABEL_AUTOTEXT_EMAIL_5,"%s")
 dcl(MENU_LABEL_AUTOTEXT_EMAIL_6,"%s")
-dcl(MENU_LABEL_FMT_IMAGE, "Resize &Image")
 
 dcl(MENU_STATUSLINE__BOGUS1__," ")
 dcl(MENU_STATUSLINE__BOGUS2__," ")
 dcl(MENU_STATUSLINE_OPEN_TEMPLATE," ")
 dcl(MENU_STATUSLINE_FILE," ")
 dcl(MENU_STATUSLINE_FILE_NEW,"Create a new document"	)
+dcl(MENU_STATUSLINE_FILE_NEW_USING_TEMPLATE,"Create a new document using a template"	)
 dcl(MENU_STATUSLINE_FILE_OPEN,"Open an existing document")
 dcl(MENU_STATUSLINE_FILE_CLOSE,"Close the document")
 dcl(MENU_STATUSLINE_FILE_SAVE,"Save the document")
@@ -1033,15 +1188,19 @@ dcl(MENU_STATUSLINE_EDIT_EDITHEADER,"Edit the Header on the current page")
 dcl(MENU_STATUSLINE_EDIT_EDITFOOTER,"Edit the Footer on the current page")
 dcl(MENU_STATUSLINE_EDIT_REMOVEHEADER,"Remove the Header on this page from the Document")
 dcl(MENU_STATUSLINE_EDIT_REMOVEFOOTER,"Remove the Footer on this page from the Document")
+dcl(MENU_STATUSLINE_EDIT_DELETEFRAME,"Remove the Text Box from the Document")
+dcl(MENU_STATUSLINE_EDIT_CUT_FRAME,"Copy the Text Box to the clipboard then remove it")
+dcl(MENU_STATUSLINE_EDIT_COPY_FRAME,"Copy the Text Box to the clipboard")
+dcl(MENU_STATUSLINE_EDIT_SELECT_FRAME,"Select the Text Box")
 dcl(MENU_STATUSLINE_VIEW," ")
 dcl(MENU_STATUSLINE_VIEW_NORMAL,"Normal View")
 dcl(MENU_STATUSLINE_VIEW_WEB,"Web Layout")
 dcl(MENU_STATUSLINE_VIEW_PRINT,"Print Layout")
 dcl(MENU_STATUSLINE_VIEW_TOOLBARS," ")
-dcl(MENU_STATUSLINE_VIEW_TB_STD,"Show or hide the standard toolbar")
-dcl(MENU_STATUSLINE_VIEW_TB_FORMAT,"Show or hide the formatting toolbar")
-dcl(MENU_STATUSLINE_VIEW_TB_TABLE,"Show or hide the table toolbar")
-dcl(MENU_STATUSLINE_VIEW_TB_EXTRA,"Show or hide the extra toolbar")
+dcl(MENU_STATUSLINE_VIEW_TB_1,"Show or hide the toolbar")
+dcl(MENU_STATUSLINE_VIEW_TB_2,"Show or hide the toolbar")
+dcl(MENU_STATUSLINE_VIEW_TB_3,"Show or hide the toolbar")
+dcl(MENU_STATUSLINE_VIEW_TB_4,"Show or hide the toolbar")
 dcl(MENU_STATUSLINE_VIEW_LOCK_TB_LAYOUT,"Lock the layout of the current toolbars")
 dcl(MENU_STATUSLINE_VIEW_DEFAULT_TB_LAYOUT,"Reset the current toolbar layout to its defaults")
 dcl(MENU_STATUSLINE_VIEW_RULER,"Show or hide the rulers")
@@ -1063,19 +1222,27 @@ dcl(MENU_STATUSLINE_INSERT_BREAK,"Insert a page, column, or section break")
 dcl(MENU_STATUSLINE_INSERT_PAGENO,"Insert an automatically-updated page number")
 dcl(MENU_STATUSLINE_INSERT_DATETIME,"Insert the date and/or time")
 dcl(MENU_STATUSLINE_INSERT_FIELD,"Insert a calculated field")
+dcl(MENU_STATUSLINE_INSERT_TEXTBOX, "Insert a Text Box")
 dcl(MENU_STATUSLINE_INSERT_MAILMERGE, "Insert a mail merge field")
 dcl(MENU_STATUSLINE_INSERT_FILE,"Insert the contents of another file")
 dcl(MENU_STATUSLINE_INSERT_SYMBOL,"Insert a symbol or other special character")
 dcl(MENU_STATUSLINE_INSERT_FOOTNOTE,"Insert a footnote")
+dcl(MENU_STATUSLINE_INSERT_TABLEOFCONTENTS,"Insert a Table of Contents based on Headings")
 dcl(MENU_STATUSLINE_INSERT_ENDNOTE,"Insert an endnote")
 dcl(MENU_STATUSLINE_INSERT_PICTURE,"Insert a picture")
 dcl(MENU_STATUSLINE_INSERT_CLIPART,"Insert clipart")
-dcl(MENU_STATUSLINE_INSERT_INSERTHEADER,"Insert a Header")
-dcl(MENU_STATUSLINE_INSERT_INSERTFOOTER,"Insert a Footer")
+dcl(MENU_STATUSLINE_INSERT_HEADER,"Insert a Header")
+dcl(MENU_STATUSLINE_INSERT_FOOTER,"Insert a Footer")
 dcl(MENU_STATUSLINE_INSERT_GRAPHIC,"Insert an existing picture from another file")
 dcl(MENU_STATUSLINE_INSERT_BOOKMARK,"Insert bookmark")
 dcl(MENU_STATUSLINE_INSERT_HYPERLINK,"Insert hyperlink")
+dcl(MENU_STATUSLINE_INSERT_GOTO_HYPERLINK,"Jump to hyperlink")
+dcl(MENU_STATUSLINE_INSERT_EDIT_HYPERLINK,"Edit hyperlink")
 dcl(MENU_STATUSLINE_INSERT_DELETE_HYPERLINK,"Delete hyperlink")
+dcl(MENU_STATUSLINE_INSERT_DIRECTIONMARKER, "Insert Unicode direction marker into the document")
+dcl(MENU_STATUSLINE_INSERT_DIRECTIONMARKER_LRM, "Insert left-to-right direction marker (LRM)")
+dcl(MENU_STATUSLINE_INSERT_DIRECTIONMARKER_RLM, "Insert right-to-left direction marker (RLM)")
+
 dcl(MENU_STATUSLINE_FORMAT," ")
 dcl(MENU_STATUSLINE_FMT, " ")
 dcl(MENU_STATUSLINE_FMT_LANGUAGE,"Change the language of the selected text")
@@ -1086,9 +1253,13 @@ dcl(MENU_STATUSLINE_FMT_DOCUMENT,"Setup your document's page properties such as
 dcl(MENU_STATUSLINE_FMT_BORDERS,"Add borders and shading to the selection")
 dcl(MENU_STATUSLINE_FMT_HDRFTR,"Set the types of Headers and Footers")
 dcl(MENU_STATUSLINE_FMT_FOOTNOTES,"Set the types of Footnotes and Endnotes")
+dcl(MENU_STATUSLINE_FMT_TABLEOFCONTENTS,"Set the type and styles of the Table of Contents")
 dcl(MENU_STATUSLINE_FMT_COLUMNS,"Change the number of columns")
 dcl(MENU_STATUSLINE_FMT_TOGGLECASE,"Change the case of the selected text")
-dcl(MENU_STATUSLINE_FMT_BACKGROUND,"Change your document's background color")
+dcl(MENU_STATUSLINE_FMT_BACKGROUND,"Change your document's page background")
+dcl(MENU_STATUSLINE_FMT_BACKGROUND_PAGE_COLOR,"Change your document's page color")
+dcl(MENU_STATUSLINE_FMT_BACKGROUND_PAGE_IMAGE,"Set an image as a background for your page")
+dcl(MENU_STATUSLINE_FMT_STYLIST, "Format your document using styles")
 dcl(MENU_STATUSLINE_FMT_STYLE,"Define or apply style for the selection")
 dcl(MENU_STATUSLINE_FMT_STYLE_DEFINE, "Define or apply style for the selection")
 dcl(MENU_STATUSLINE_FMT_IMPORTSTYLES,"Import style definitions from a document")
@@ -1102,6 +1273,11 @@ dcl(MENU_STATUSLINE_FMT_TOPLINE,"Line above the selection (toggle)")
 dcl(MENU_STATUSLINE_FMT_BOTTOMLINE,"Line below the selection (toggle)")
 dcl(MENU_STATUSLINE_FMT_SUPERSCRIPT,"Make the selection superscript (toggle)")
 dcl(MENU_STATUSLINE_FMT_SUBSCRIPT,"Make the selection subscript (toggle)")
+dcl(MENU_STATUSLINE_FMT_FRAME,"Change the properties of the Text Box")
+dcl(MENU_STATUSLINE_FMT_DIRECTION, "Change directional properties of text")
+dcl(MENU_STATUSLINE_FMT_DIRECTION_DD_RTL, "Set dominant direction of paragraph to RTL")
+dcl(MENU_STATUSLINE_FMT_DIRECTION_DO_LTR, "Force left-to-right direction of text")
+dcl(MENU_STATUSLINE_FMT_DIRECTION_DO_RTL, "Force right-to-left direction of text")
 dcl(MENU_STATUSLINE_TOOLS," "	)
 dcl(MENU_STATUSLINE_TOOLS_SPELLING," ")
 dcl(MENU_STATUSLINE_TOOLS_SPELL,"Check the document for incorrect spelling")
@@ -1113,11 +1289,22 @@ dcl(MENU_STATUSLINE_TOOLS_LANGUAGE,"Change the language of the selected text")
 dcl(MENU_STATUSLINE_TOOLS_PLUGINS,"Manage plugins")
 dcl(MENU_STATUSLINE_TOOLS_MAILMERGE, "Mail Merge")
 dcl(MENU_STATUSLINE_TOOLS_SCRIPTS,"Execute helper scripts")
+dcl(MENU_STATUSLINE_TOOLS_HISTORY,"See history of the current document")
+dcl(MENU_STATUSLINE_TOOLS_HISTORY_SHOW,"View document history")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS,"Manage changes in document")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS_SET_VIEW_LEVEL,"Choose which revision you wish to view")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS_MARK,"Mark changes as you type")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_SHOW,"Show revisions that are present in document")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_SHOW_AFTER,"Show what the document looks like after revisions")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_SHOW_AFTERPREV,"Show what the document looks like after previous revisions")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_SHOW_BEFORE,"Show what the document looks like before revisions")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS_ACCEPT_REVISION,"Accept the suggested change")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS_REJECT_REVISION,"Remove the suggested change")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_FIND_NEXT,"Find next visible revision in the document")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_FIND_PREV,"Find previous visible revision in the document")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_COMPARE_DOCUMENTS,"Compare active document to another document")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_MERGE_DOCUMENTS,"Merge another document into the active document using revision marks")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS_AUTO,"Retain all document changes")
 dcl(MENU_STATUSLINE_TABLE, "Table")
 dcl(MENU_STATUSLINE_TABLE_INSERT, "Insert")
 dcl(MENU_STATUSLINE_TABLE_INSERT_TABLE, "Insert Table")
@@ -1149,10 +1336,18 @@ dcl(MENU_STATUSLINE_TABLE_FORMAT, "Format Table")
 dcl(MENU_STATUSLINE_TABLE_AUTOFIT, "Autofit Table")
 dcl(MENU_STATUSLINE_TABLE_HEADING_ROWS_REPEAT, "Repeat Row as Heading")
 dcl(MENU_STATUSLINE_TABLE_SORT, "Sort Table")
-
+dcl(MENU_STATUSLINE_TABLE_TEXTTOTABLE, "Convert Selected Text to a Table")
+dcl(MENU_STATUSLINE_TABLE_SORTROWSASCEND, "Sort Rows in Ascending Order based on selected Column")
+dcl(MENU_STATUSLINE_TABLE_SORTROWSDESCEND, "Sort Rows in Descending Order based on Selected Column")
+dcl(MENU_STATUSLINE_TABLE_SORTCOLSASCEND, "Sort Columns in Ascending Order based on Selected Row")
+dcl(MENU_STATUSLINE_TABLE_SORTCOLSDESCEND, "Sort Columns in Descending Order based on Selected Row")
+dcl(MENU_STATUSLINE_TABLE_INSERT_SUMCOLS, "Insert the Sum of a Table Row")
+dcl(MENU_STATUSLINE_TABLE_INSERT_SUMROWS, "Insert the Sum of a Table Column")
 #define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_REVISIONS_ACCEPT_REVISION AP_STRING_ID_MENU_STATUSLINE_TOOLS_REVISIONS_ACCEPT_REVISION
 #define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_REVISIONS_REJECT_REVISION AP_STRING_ID_MENU_STATUSLINE_TOOLS_REVISIONS_REJECT_REVISION
-	dcl(MENU_STATUSLINE_ALIGN," ")
+#define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_REVISIONS_FIND_NEXT AP_STRING_ID_MENU_STATUSLINE_TOOLS_REVISIONS_FIND_NEXT
+#define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_REVISIONS_FIND_PREV AP_STRING_ID_MENU_STATUSLINE_TOOLS_REVISIONS_FIND_PREV
+dcl(MENU_STATUSLINE_ALIGN," ")
 dcl(MENU_STATUSLINE_ALIGN_LEFT,"Left-align the paragraph")
 dcl(MENU_STATUSLINE_ALIGN_CENTER,"Center-align the paragraph")
 dcl(MENU_STATUSLINE_ALIGN_RIGHT,"Right-align the paragraph")
@@ -1239,6 +1434,11 @@ dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_5," ")
 dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_6," ")
 dcl(MENU_STATUSLINE_FMT_IMAGE, "Resize this image")
 
+/* Toolbar labels */
+dcl(TB_Extra,"Extra")
+dcl(TB_Format,"Format")
+dcl(TB_Standard,"Standard")
+dcl(TB_Table,"Table")
 
 dcl(TOOLBAR_LABEL_FILE_NEW,"New")
 dcl(TOOLBAR_LABEL_FILE_OPEN,"Open")
